Trait Key
pub trait Key: Send + Sync {
// Required methods
fn sign_concat(&self, first: &[u8], middle: &[&[u8]], last: &[u8]) -> Tag;
fn tag_len(&self) -> usize;
// Provided method
fn sign(&self, data: &[&[u8]]) -> Tag { ... }
}Available on crate feature
tls only.Expand description
A HMAC key that is ready for use.
The algorithm used is implicit in the Hmac object that produced the key.
Required Methods
fn sign_concat(&self, first: &[u8], middle: &[&[u8]], last: &[u8]) -> Tag
fn sign_concat(&self, first: &[u8], middle: &[&[u8]], last: &[u8]) -> Tag
Calculates a tag over the concatenation of first, the items in middle, and last.
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".